@@ -7,18 +7,28 @@ from time import sleep
 
 class LightSensor:
 
-    def __init__(self, sampling_rate_sec: int = 1, smoothing_window_sec: int = 15):
+    def __init__(self, sampling_rate_sec: int = 1, smoothing_window_sec: int = 15, refreshing_rate_sec:int=1):
         self.smoothing_window_sec = smoothing_window_sec
         self.sampling_rate_sec = sampling_rate_sec
+        self.refreshing_rate_sec = refreshing_rate_sec
         self.measures = list()
         i2c = board.I2C()
         self.sensor = adafruit_bh1750.BH1750(i2c)
         logging.info("light sensor connected")
 
-    def listen(self, listener, refreshing_rate_sec:int=1):
-        Thread(target=self.__listen, args=(listener,refreshing_rate_sec), daemon=True).start()
+    def update_smoothing_window(self, smoothing_window_sec: int):
+        self.smoothing_window_sec = smoothing_window_sec
 
-    def __listen(self, listener, refreshing_rate_sec):
+    def update_sampling_rate(self, sampling_rate_sec: int):
+        self.sampling_rate_sec = sampling_rate_sec
+
+    def update_refreshing_rate(self, refreshing_rate_sec: int):
+        self.refreshing_rate_sec = refreshing_rate_sec
+
+    def listen(self, listener):
+        Thread(target=self.__listen, args=(listener,), daemon=True).start()
+
+    def __listen(self, listener):
         loop = 0
         while True:
             try:
@@ -26,7 +36,7 @@ class LightSensor:
                 while len(self.measures) > self.smoothing_window_sec:
                     self.measures.pop(0)
                 loop +=1
-                if loop > refreshing_rate_sec:
+                if loop >= self.refreshing_rate_sec:
                     loop = 0
                     sorted_measures = sorted(self.measures)
                     median = sorted_measures[int(len(sorted_measures) * 0.5)]
@@ -35,11 +45,3 @@ class LightSensor:
                 print("error occurred", e)
             sleep(self.sampling_rate_sec)
 
-
-def show(lux):
-    print(lux)
-
-lightSensor = LightSensor()
-lightSensor.listen(show)
-
-sleep(100000)
\ No newline at end of file
